==> haskell-iospec-0.3.1.2-118-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-iospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 IOSpec
version:              0.3.1.2
visibility:           public
id:                   IOSpec-0.3.1.2-9GkL1hkciwXBwy9FDfWgr1
key:                  IOSpec-0.3.1.2-9GkL1hkciwXBwy9FDfWgr1
license:              BSD-3-Clause
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:
    Wouter Swierstra,
    Yusaku Hashimoto,
    Nikolay Amiantov,
    Bertram Felgenhauer

homepage:             https://github.com/lambdabot/IOSpec
synopsis:             A pure specification of the IO monad.
description:
    This package consists of several modules, that give a
    pure specification of functions in the IO monad:

    * "Test.IOSpec.Fork": a pure specification of
    '\''forkIO'\''.
    * "Test.IOSpec.IORef": a pure specification of most
    functions that create and manipulate on '\''IORefs'\''.
    * "Test.IOSpec.MVar": a pure specification of most
    functions that create and manipulate and '\''MVars'\''.
    * "Test.IOSpec.STM": a pure specification of
    '\''atomically'\'' and the '\''STM'\'' monad.
    * "Test.IOSpec.Teletype": a pure specification of
    '\''getChar'\'', '\''putChar'\'', and several related
    Prelude functions.

    Besides these modules containing the specifications,
    there are a few other important modules:

    * "Test.IOSpec.Types": defines the '\''IOSpec'\'' type and
    several amenities.
    * "Test.IOSpec.VirtualMachine": defines a virtual
    machine on which to execute pure specifications.
    * "Test.IOSpec.Surrogate": a drop-in replacement for
    the other modules. Import this and recompile your
    code once you'\''ve finished testing and debugging.

    There are several well-documented examples included
    with the source distribution.

category:             Testing
abi:                  581d9d2aadbba4bca842455c2140d7e7
exposed:              True
exposed-modules:
    Test.IOSpec Test.IOSpec.Fork Test.IOSpec.IORef Test.IOSpec.MVar
    Test.IOSpec.STM Test.IOSpec.Surrogate Test.IOSpec.Teletype
    Test.IOSpec.Types Test.IOSpec.VirtualMachine

import-dirs:          /usr/lib/ghc-9.4.8/site-local/IOSpec-0.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/IOSpec-0.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/IOSpec-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iospec
hs-libraries:         HSIOSpec-0.3.1.2-9GkL1hkciwXBwy9FDfWgr1
depends:
    QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo
    Stream-0.4.7.2-GXRJd5nmacwEtvjVNFprzj base-4.17.2.1 mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-iospec/html/IOSpec.haddock
haddock-html:         /usr/share/doc/haskell-iospec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iospec-0.3.1.2-123-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-iospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 IOSpec
version:              0.3.1.2
visibility:           public
id:                   IOSpec-0.3.1.2-5w2efXijgj36BZV7MEmpG6
key:                  IOSpec-0.3.1.2-5w2efXijgj36BZV7MEmpG6
license:              BSD-3-Clause
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:
    Wouter Swierstra,
    Yusaku Hashimoto,
    Nikolay Amiantov,
    Bertram Felgenhauer

homepage:             https://github.com/lambdabot/IOSpec
synopsis:             A pure specification of the IO monad.
description:
    This package consists of several modules, that give a
    pure specification of functions in the IO monad:

    * "Test.IOSpec.Fork": a pure specification of
    '\''forkIO'\''.
    * "Test.IOSpec.IORef": a pure specification of most
    functions that create and manipulate on '\''IORefs'\''.
    * "Test.IOSpec.MVar": a pure specification of most
    functions that create and manipulate and '\''MVars'\''.
    * "Test.IOSpec.STM": a pure specification of
    '\''atomically'\'' and the '\''STM'\'' monad.
    * "Test.IOSpec.Teletype": a pure specification of
    '\''getChar'\'', '\''putChar'\'', and several related
    Prelude functions.

    Besides these modules containing the specifications,
    there are a few other important modules:

    * "Test.IOSpec.Types": defines the '\''IOSpec'\'' type and
    several amenities.
    * "Test.IOSpec.VirtualMachine": defines a virtual
    machine on which to execute pure specifications.
    * "Test.IOSpec.Surrogate": a drop-in replacement for
    the other modules. Import this and recompile your
    code once you'\''ve finished testing and debugging.

    There are several well-documented examples included
    with the source distribution.

category:             Testing
abi:                  9b01f5b58bf61288412bc484dad80bdb
exposed:              True
exposed-modules:
    Test.IOSpec Test.IOSpec.Fork Test.IOSpec.IORef Test.IOSpec.MVar
    Test.IOSpec.STM Test.IOSpec.Surrogate Test.IOSpec.Teletype
    Test.IOSpec.Types Test.IOSpec.VirtualMachine

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/IOSpec-0.3.1.2
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/IOSpec-0.3.1.2
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/IOSpec-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iospec
hs-libraries:         HSIOSpec-0.3.1.2-5w2efXijgj36BZV7MEmpG6
depends:
    QuickCheck-2.15.0.1-Lq4ECkPzV8iDkKvRhPZIAs
    Stream-0.4.7.2-82KxZt4XHiosIwUBO8KuK base-4.18.3.0 mtl-2.3.1

haddock-interfaces:   /usr/share/doc/haskell-iospec/html/IOSpec.haddock
haddock-html:         /usr/share/doc/haskell-iospec/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
